require 'test-strings/clipboard'
require 'test-strings/copy-util'

def copy(string)
  assert_no_nulls(string)
  Win32::Clipboard.set_data(string)   #<callout id="co.first.module"/>
  true
end

def unicopy(hex_name_array)
  assert_names_of_acceptable_length(hex_name_array)
  hex_name_array = zero_pad(hex_name_array)
  assert_no_null_bytes(hex_name_array)

  Win32::Clipboard.set_data(win32unicode(hex_name_array),
                            Win32::Clipboard::UNICODETEXT)
  true
end

# Utilities

def assert_no_nulls(string)
  if string.include?("\000")
    raise StandardError.new("Null characters are not allowed in the string to be copied: '#{string}'")
  end
end

def assert_no_null_bytes(hex_name_array)
  hex_name_array.each do | name |
    if name[0,2] == '00' or name[2,2] == '00'
      raise StandardError.new("This method cannot paste unicode characters of the form 00xx or xx00 onto the clipboard: '#{name}'")
    end
  end
end

def zero_pad(hex_name_array)
  hex_name_array.collect { | name |
    '0' * (4 - name.length) + name
  }
end

def extract_flipped_bytes(unicode_char_string)
  [unicode_char_string[2,2].to_i(16),
    unicode_char_string[0,2].to_i(16)]
end


def win32unicode(unicode_char_strings)
  flipped_bytes = unicode_char_strings.collect do | str |
    extract_flipped_bytes(str)
  end
  flipped_bytes.flatten.pack('C*')
end

