if /win32/ =~ RUBY_PLATFORM
  require 'test/unit'
  require 'test-strings'
  require 'test-strings/clipboard'
  require 'test-util'

  class  Win32CopyTests < Test::Unit::TestCase
    include Win32

    def test_copy
      # Pick a name unlikely to already be on the clipboard.
      string = "windows clipboard test " + rand(1000000).to_s
      
      copy(string)
      assert(string, Clipboard.get_data)
    end

    def test_copy_cannot_copy_zero_byte
      assert_raises_with_message(StandardError,
                                 "Null characters are not allowed in the string to be copied: 'a\000\b'") {
        copy("a\000\b")
      }
    end


    def test_unicopy
      characters = %w{16e2 3a6}
      unicopy(characters)

      # Read back and compare to original. Note that it comes back in
      # byte-swapped format. What this tests is that the same thing happened
      # as last time the test ran. You'll have to check by hand that the result
      # is a real, pasteable Unicode character. 

      pasted = Clipboard.get_data(Clipboard::UNICODETEXT)
      assert_equal([0xe2, 0x16, 0xa6, 0x03],
                        pasted.unpack('C*'))
    end

    def test_unicopy_rejects_ordinary_text_because_of_zero_byte
      assert_raises_with_message(StandardError, "This method cannot paste unicode characters of the form 00xx or xx00 onto the clipboard: '0042'") {
        unicopy(%w{ 42 })
      }

      assert_raises_with_message(StandardError, "This method cannot paste unicode characters of the form 00xx or xx00 onto the clipboard: '4200'") {
        unicopy(%w{ 4200 })
      }

    end

    # Test utility methods

    def test_flipping_of_unicode_chars
      assert_equal([0x02, 0xb3], extract_flipped_bytes("b302"))
    end
    
    def test_win32unicode_reverses_bytes
      uni = %w{ 03b3 }
      assert_equal("\263\03", win32unicode(uni))
      uni = %w{ 03b3 03b2 03b1 }
      assert_equal("\263\03\262\03\261\03", win32unicode(uni))
    end

    def test_high_order_bit_treated_as_unsigned
      # I know b3 is unsigned above, but this is more explicit.
      uni = %w{ fff0 }
      assert_equal("\360\377", win32unicode(uni))
    end
  end
end

